@@ -18,6 +18,12 @@ setClass("Survey", representation(population = "Population",
 
 #' @param x object of class Survey
 #' @param y NULL
+#' @param type character specifies which plots you would like, defaults to "all".
+#' Other options include "transects", "population", "survey" and "distances". These
+#' will plot only the transects, only the population locations, both the transects
+#' and population with detections indicated or a histogram of the detection distances,
+#' respectively. Note that the final plots is only available if there were
+#' one or more detections.
 #' @param ... additional plotting parameters
 #' @return Generate 4 plots showing the survey population, transects (including covered areas), detections and a histogram of the detection distances. Plots include the survey region. Also invisibly returns a list of ggplot objects if the user would like to customise the plots.
 #' @rdname plot-methods
@@ -31,8 +37,12 @@ setClass("Survey", representation(population = "Population",
 setMethod(
   f="plot",
   signature=c("Survey", "Region"),
-  definition=function(x, y, ...){
+  definition=function(x, y, type = "all", ...){
     # Set up plot parameters
+    # Check type input
+    if(!type %in% c("transects", "population", "survey", "distances", "all")){
+      stop("Plotting argument type not recognised. Please use 'survey', 'distances' or 'all'", call. = FALSE)
+    }
     # 4 plot for survey
     suppressWarnings(invisible(gc()))
     p <- list()
@@ -44,6 +54,10 @@ setMethod(
       geom_sf(data = sf.region, color = gray(.2), lwd = 0.1) +
       geom_sf(data = transects, mapping = aes(), colour = "blue") +
       ggtitle("Transects")
+    # If user only wants transects
+    if(type == "transects"){
+      return(p[[1]])
+    }
 
     pop.df <- x@population@population
     pts <- sp::SpatialPoints(data.frame(x = pop.df$x, y = pop.df$y))
@@ -54,6 +68,10 @@ setMethod(
       geom_sf(data = sf.region, color = gray(.2), lwd = 0.1, fill = "lightgrey") +
       geom_sf(data = pts.sf, mapping = aes(), colour = "red", cex = 0.5) +
       ggtitle("Population")
+    # If user only wants population
+    if(type == "population"){
+      return(p[[2]])
+    }
 
     distdata <- na.omit(x@dist.data)
     if(nrow(distdata) > 0){
@@ -67,6 +85,10 @@ setMethod(
         geom_sf(data = pts.sf, mapping = aes(), colour = "red", cex = 0.5) +
         geom_sf(data = detect.sf, mapping = aes(), colour = "cyan", cex = 1) +
         ggtitle("Detections")
+      # If user only wants transects
+      if(type == "survey"){
+        return(p[[3]])
+      }
 
       bins <- nclass.Sturges(distdata$distance)
       breaks <- seq(0, max(na.omit(distdata$distance)), length = bins)
@@ -77,14 +99,23 @@ setMethod(
                        fill="grey",
                        alpha = .2) +
         labs(title="Detection Distances", x="distance")
+      if(type == "distances"){
+        return(p[[4]])
+      }
 
     }else{
-      warning("No detections", immediate. = TRUE, call. = FALSE)
       p[[3]] <- ggplot() + theme_void() +
         geom_sf(data = sf.region, color = gray(.2), lwd = 0.1) +
         geom_sf(data = transects, mapping = aes(), colour = "blue") +
         geom_sf(data = pts.sf, mapping = aes(), colour = "red", cex = 0.5) +
         ggtitle("Detections")
+      if(type == "survey"){
+        return(p[[3]])
+      }
+      if(type == "distances"){
+        warning("There are no detections, cannot display a histogram of detection distances.", immediate. = TRUE, call. = FALSE)
+        return(invisible(NULL))
+      }
     }
 
     gridExtra::grid.arrange(grobs=p)
@@ -100,7 +131,14 @@ setMethod(
 #' plots 3 & 4 are generated without the survey region if Region is omitted.
 #'
 #' @param x object of class Survey
-#' @param y object of class Region
+#' @param y object of class Region or NULL
+#' @param type character specifies which plots you would like, defaults to "all".
+#' Other options include "transects", "population", "survey" and "distances". These
+#' will plot only the transects, only the population locations, both the transects
+#' and population with detections indicated or a histogram of the detection distances,
+#' respectively. Note that the final plots is only available if there were
+#' one or more detections. Only "survey" and "distances" available if the y
+#' Region argument is not supplied.
 #' @param ... additional plotting parameters
 #' @return Generate 2 plots showing the survey population, transects (including covered areas), detections and a histogram of the detection distances. Plots do not include survey region. Also invisibly returns a list of ggplot objects if the user would like to customise the plots.
 #' @rdname plot-methods
@@ -114,8 +152,12 @@ setMethod(
 setMethod(
   f="plot",
   signature=c("Survey"),
-  definition=function(x, y = NULL, ...){
+  definition=function(x, y = NULL, type = "all", ...){
     suppressWarnings(invisible(gc()))
+    # Check type input
+    if(!type %in% c("survey", "distances", "all")){
+      stop("Plotting argument type not recognised. Please use 'survey', 'distances' or 'all' when Region not supplied.", call. = FALSE)
+    }
     p <- list()
     # Set up data
     # Transects
@@ -139,6 +181,9 @@ setMethod(
         geom_sf(data = pts.sf, mapping = aes(), colour = "red", cex = 0.5) +
         geom_sf(data = detect.sf, mapping = aes(), colour = "cyan", cex = 1) +
         ggtitle("Example survey")
+      if(type == "survey"){
+        return(p[[1]])
+      }
 
       bins <- nclass.Sturges(distdata$distance)
       breaks <- seq(0, max(distdata$distance), length = bins)
@@ -150,18 +195,25 @@ setMethod(
                        fill="grey",
                        alpha = .2) +
         labs(title="Detection Distances", x="distance")
+      if(type == "distances"){
+        return(p[[2]])
+      }
     }else{
-      warning("No detections", immediate. = TRUE, call. = FALSE)
       p[[1]] <- ggplot() + theme_void() +
         geom_sf(data = covered.areas, color = gray(.2), lwd = 0.1) +
         geom_sf(data = transects, mapping = aes(), colour = "blue") +
         geom_sf(data = pts.sf, mapping = aes(), colour = "red", cex = 0.5) +
         ggtitle("Example survey")
+      if(type == "survey"){
+        return(p[[1]])
+      }
+      if(type == "distances"){
+        warning("There are no detections, cannot display a histogram of detection distances.", immediate. = TRUE, call. = FALSE)
+        return(invisible(NULL))
+      }
     }
-
-
+    
     gridExtra::grid.arrange(grobs=p)
-
     invisible(p)
   }
 )
